@@ -121,22 +121,22 @@ from typeguard import check_type
 
 from ._jsii import *
 
-import aws_cdk.aws_stepfunctions
-import constructs
+import aws_cdk.aws_stepfunctions as _aws_cdk_aws_stepfunctions_ceddda9d
+import constructs as _constructs_77d1e7e8
 
 
 @jsii.interface(jsii_type="@dontirun/state-machine-semaphore.IChainNextable")
 class IChainNextable(
-    aws_cdk.aws_stepfunctions.IChainable,
-    aws_cdk.aws_stepfunctions.INextable,
+    _aws_cdk_aws_stepfunctions_ceddda9d.IChainable,
+    _aws_cdk_aws_stepfunctions_ceddda9d.INextable,
     typing_extensions.Protocol,
 ):
     pass
 
 
 class _IChainNextableProxy(
-    jsii.proxy_for(aws_cdk.aws_stepfunctions.IChainable), # type: ignore[misc]
-    jsii.proxy_for(aws_cdk.aws_stepfunctions.INextable), # type: ignore[misc]
+    jsii.proxy_for(_aws_cdk_aws_stepfunctions_ceddda9d.IChainable), # type: ignore[misc]
+    jsii.proxy_for(_aws_cdk_aws_stepfunctions_ceddda9d.INextable), # type: ignore[misc]
 ):
     __jsii_type__: typing.ClassVar[str] = "@dontirun/state-machine-semaphore.IChainNextable"
     pass
@@ -146,7 +146,7 @@ typing.cast(typing.Any, IChainNextable).__jsii_proxy_class__ = lambda : _IChainN
 
 
 class Semaphore(
-    aws_cdk.aws_stepfunctions.StateMachineFragment,
+    _aws_cdk_aws_stepfunctions_ceddda9d.StateMachineFragment,
     metaclass=jsii.JSIIMeta,
     jsii_type="@dontirun/state-machine-semaphore.Semaphore",
 ):
@@ -154,16 +154,16 @@ class Semaphore(
 
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id: builtins.str,
         *,
         job: IChainNextable,
         limit: jsii.Number,
         lock_name: builtins.str,
-        next_state: aws_cdk.aws_stepfunctions.State,
+        next_state: _aws_cdk_aws_stepfunctions_ceddda9d.State,
         comments: typing.Optional[builtins.bool] = None,
         reuse_lock: typing.Optional[builtins.bool] = None,
-        table_read_write_capacity: typing.Optional[typing.Union["TableReadWriteCapacity", typing.Dict[str, typing.Any]]] = None,
+        table_read_write_capacity: typing.Optional[typing.Union["TableReadWriteCapacity", typing.Dict[builtins.str, typing.Any]]] = None,
     ) -> None:
         '''
         :param scope: -
@@ -177,20 +177,7 @@ class Semaphore(
         :param table_read_write_capacity: Optionally set the DynamoDB table to have a specific read/write capacity with PROVISIONED billing. Note: This property can only be set on the first instantiation of a ``Semaphore`` per stack Default: PAY_PER_REQUEST
         '''
         if __debug__:
-            def stub(
-                scope: constructs.Construct,
-                id: builtins.str,
-                *,
-                job: IChainNextable,
-                limit: jsii.Number,
-                lock_name: builtins.str,
-                next_state: aws_cdk.aws_stepfunctions.State,
-                comments: typing.Optional[builtins.bool] = None,
-                reuse_lock: typing.Optional[builtins.bool] = None,
-                table_read_write_capacity: typing.Optional[typing.Union[TableReadWriteCapacity, typing.Dict[str, typing.Any]]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__6ca016e78c06471897f94d1abe25cb73671af597e2e20eda476d7afe2fe8b547)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = SemaphoreProps(
@@ -207,15 +194,15 @@ class Semaphore(
 
     @builtins.property
     @jsii.member(jsii_name="endStates")
-    def end_states(self) -> typing.List[aws_cdk.aws_stepfunctions.INextable]:
+    def end_states(self) -> typing.List[_aws_cdk_aws_stepfunctions_ceddda9d.INextable]:
         '''The states to chain onto if this fragment is used.'''
-        return typing.cast(typing.List[aws_cdk.aws_stepfunctions.INextable], jsii.get(self, "endStates"))
+        return typing.cast(typing.List[_aws_cdk_aws_stepfunctions_ceddda9d.INextable], jsii.get(self, "endStates"))
 
     @builtins.property
     @jsii.member(jsii_name="startState")
-    def start_state(self) -> aws_cdk.aws_stepfunctions.State:
+    def start_state(self) -> _aws_cdk_aws_stepfunctions_ceddda9d.State:
         '''The start state of this state machine fragment.'''
-        return typing.cast(aws_cdk.aws_stepfunctions.State, jsii.get(self, "startState"))
+        return typing.cast(_aws_cdk_aws_stepfunctions_ceddda9d.State, jsii.get(self, "startState"))
 
 
 @jsii.data_type(
@@ -238,10 +225,10 @@ class SemaphoreProps:
         job: IChainNextable,
         limit: jsii.Number,
         lock_name: builtins.str,
-        next_state: aws_cdk.aws_stepfunctions.State,
+        next_state: _aws_cdk_aws_stepfunctions_ceddda9d.State,
         comments: typing.Optional[builtins.bool] = None,
         reuse_lock: typing.Optional[builtins.bool] = None,
-        table_read_write_capacity: typing.Optional[typing.Union["TableReadWriteCapacity", typing.Dict[str, typing.Any]]] = None,
+        table_read_write_capacity: typing.Optional[typing.Union["TableReadWriteCapacity", typing.Dict[builtins.str, typing.Any]]] = None,
     ) -> None:
         '''Interface for creating a Semaphore.
 
@@ -256,18 +243,7 @@ class SemaphoreProps:
         if isinstance(table_read_write_capacity, dict):
             table_read_write_capacity = TableReadWriteCapacity(**table_read_write_capacity)
         if __debug__:
-            def stub(
-                *,
-                job: IChainNextable,
-                limit: jsii.Number,
-                lock_name: builtins.str,
-                next_state: aws_cdk.aws_stepfunctions.State,
-                comments: typing.Optional[builtins.bool] = None,
-                reuse_lock: typing.Optional[builtins.bool] = None,
-                table_read_write_capacity: typing.Optional[typing.Union[TableReadWriteCapacity, typing.Dict[str, typing.Any]]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__6d2f3ae3c8824281d16f1458e27897f16c6c26c278e4f199e1b9074cc3c6e9ed)
             check_type(argname="argument job", value=job, expected_type=type_hints["job"])
             check_type(argname="argument limit", value=limit, expected_type=type_hints["limit"])
             check_type(argname="argument lock_name", value=lock_name, expected_type=type_hints["lock_name"])
@@ -275,7 +251,7 @@ class SemaphoreProps:
             check_type(argname="argument comments", value=comments, expected_type=type_hints["comments"])
             check_type(argname="argument reuse_lock", value=reuse_lock, expected_type=type_hints["reuse_lock"])
             check_type(argname="argument table_read_write_capacity", value=table_read_write_capacity, expected_type=type_hints["table_read_write_capacity"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "job": job,
             "limit": limit,
             "lock_name": lock_name,
@@ -310,11 +286,11 @@ class SemaphoreProps:
         return typing.cast(builtins.str, result)
 
     @builtins.property
-    def next_state(self) -> aws_cdk.aws_stepfunctions.State:
+    def next_state(self) -> _aws_cdk_aws_stepfunctions_ceddda9d.State:
         '''The State to go to after the semaphored job completes.'''
         result = self._values.get("next_state")
         assert result is not None, "Required property 'next_state' is missing"
-        return typing.cast(aws_cdk.aws_stepfunctions.State, result)
+        return typing.cast(_aws_cdk_aws_stepfunctions_ceddda9d.State, result)
 
     @builtins.property
     def comments(self) -> typing.Optional[builtins.bool]:
@@ -375,16 +351,10 @@ class TableReadWriteCapacity:
         :param write_capacity: 
         '''
         if __debug__:
-            def stub(
-                *,
-                read_capacity: jsii.Number,
-                write_capacity: jsii.Number,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__41776ce502c4c07b0e8f4089e3749a4a09d5b71f2709854181ab4bbe4dcfffef)
             check_type(argname="argument read_capacity", value=read_capacity, expected_type=type_hints["read_capacity"])
             check_type(argname="argument write_capacity", value=write_capacity, expected_type=type_hints["write_capacity"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "read_capacity": read_capacity,
             "write_capacity": write_capacity,
         }
@@ -421,3 +391,39 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__6ca016e78c06471897f94d1abe25cb73671af597e2e20eda476d7afe2fe8b547(
+    scope: _constructs_77d1e7e8.Construct,
+    id: builtins.str,
+    *,
+    job: IChainNextable,
+    limit: jsii.Number,
+    lock_name: builtins.str,
+    next_state: _aws_cdk_aws_stepfunctions_ceddda9d.State,
+    comments: typing.Optional[builtins.bool] = None,
+    reuse_lock: typing.Optional[builtins.bool] = None,
+    table_read_write_capacity: typing.Optional[typing.Union[TableReadWriteCapacity, typing.Dict[builtins.str, typing.Any]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__6d2f3ae3c8824281d16f1458e27897f16c6c26c278e4f199e1b9074cc3c6e9ed(
+    *,
+    job: IChainNextable,
+    limit: jsii.Number,
+    lock_name: builtins.str,
+    next_state: _aws_cdk_aws_stepfunctions_ceddda9d.State,
+    comments: typing.Optional[builtins.bool] = None,
+    reuse_lock: typing.Optional[builtins.bool] = None,
+    table_read_write_capacity: typing.Optional[typing.Union[TableReadWriteCapacity, typing.Dict[builtins.str, typing.Any]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__41776ce502c4c07b0e8f4089e3749a4a09d5b71f2709854181ab4bbe4dcfffef(
+    *,
+    read_capacity: jsii.Number,
+    write_capacity: jsii.Number,
+) -> None:
+    """Type checking stubs"""
+    pass
